jacinle.image.imgproc
=====================

.. automodule:: jacinle.image.imgproc

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      ShuffleType
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      brightness
      center_crop
      clip
      clip_decorator
      contrast
      crop
      dimshuffle
      grayscale
      leftup_crop
      resize
      resize_minmax
      resize_scale
      resize_scale_wh
      resize_wh
      saturation
   
   

   
   
   








.. rubric:: Class ShuffleType
.. autoclass:: ShuffleType
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: brightness

.. autofunction:: center_crop

.. autofunction:: clip

.. autofunction:: clip_decorator

.. autofunction:: contrast

.. autofunction:: crop

.. autofunction:: dimshuffle

.. autofunction:: grayscale

.. autofunction:: leftup_crop

.. autofunction:: resize

.. autofunction:: resize_minmax

.. autofunction:: resize_scale

.. autofunction:: resize_scale_wh

.. autofunction:: resize_wh

.. autofunction:: saturation


